@@ -231,6 +231,8 @@ This check should succeed.
 """
 
 # Minimal import here to speedup the loading of this module.
+# Notice that we should not import any required package here, or
+# setup will fail (this package is imported to find our requirements).
 
 from typing import List as _List
 import sys as _sys
@@ -254,9 +256,9 @@ def _process_macports(macports: _List[str]) -> _List[str]:
     import re
     l = []
     for d in _required_:
-      d=re.sub(">.*$","",d) # remove versions
-      d=re.sub("^pyyaml$","yaml",d) # fix yaml
-      l.append("py-" + d)
+        d = re.sub(">.*$", "", d)  # remove versions
+        d = re.sub("^pyyaml$", "yaml", d)  # fix yaml
+        l.append("py-" + d)
     return l
 
 _macports_required_ = _process_macports(_required_)
@@ -375,7 +377,7 @@ def describe_submodule(module: str) -> str:
     """
     import os
     import ast
-    if module != "" and not module in list_submodules(_hidden=True):
+    if module != "" and module not in list_submodules(_hidden=True):
         raise ModuleNotFoundError(module)
     if module == "":
         module = "__init__"
@@ -408,5 +410,5 @@ if _sys.version_info >= (3, 7):
         raise AttributeError(f"module '{__name__}' has no attribute '{name}'")
 
     def __dir__():
-# if later on we support __all__, globals() should be replaced by __all__
+        # if later on we support __all__, globals() should be replaced by __all__
         return sorted(list(globals()) + list_submodules(_hidden=True))
